# arpes.plotting.parameter module

**arpes.plotting.parameter.plot\_parameter(fit\_data:
xarray.core.dataarray.DataArray, param\_name: str, ax=None,
fillstyle='none', shift=0, x\_shift=0, markersize=8, title=None,
out=None, two\_sigma=False,**kwargs)\*\*
